@@ -34,7 +34,8 @@ LatexGenerator::LatexGenerator()
     : CodeGenerator ( LATEX ),
       replaceQuotes ( false ),
       disableBabelShortHand ( false ),
-      prettySymbols ( false )
+      prettySymbols ( false ),
+      beamerMode ( false )
 {
     // avoid "Underfull \hbox (badness 10000)" warnings
     newLineTag = "\\\\\n";
@@ -52,7 +53,8 @@ LatexGenerator::~LatexGenerator()
 
 void LatexGenerator::printBody()
 {
-    *out << "\\noindent\n" ;
+   // if (!beamerMode)
+        *out << "\\noindent\n" ;
     if ( ! this->getBaseFont().empty() )
         *out << "\\" << this->getBaseFont() << "\n" ;
     else
@@ -76,11 +78,14 @@ string LatexGenerator::getHeader()
 {
     ostringstream os;
 
-    os << "\\documentclass{article}\n"
+    os << (beamerMode ? "\\documentclass{beamer}\n" : "\\documentclass{article}\n")
        << "\\usepackage{color}\n"
        << "\\usepackage{alltt}\n"
        << "\\usepackage[T1]{fontenc}\n";
-
+       
+    //if (beamerMode)
+    //    os  << "\\usepackage{beamerarticle}\n";
+    
     if ( StringTools::change_case ( encoding ) == "utf-8" ) {
         os << "\\usepackage{ucs}\n\\usepackage[utf8x]{inputenc}\n";
     } else if ( encodingDefined() ) {
@@ -106,6 +111,9 @@ string LatexGenerator::getHeader()
     os << "\n\\title{" << docTitle << "}\n"
        << "\\begin{document}\n"
        << "\\pagecolor{bgcolor}\n";
+       
+    if (beamerMode)
+      os  << "\\frame{\\frametitle{Code section}\n";
 
     if ( prettySymbols ) {
         os<<"\\newsavebox{\\hlboxopenbrace}\n"
@@ -144,6 +152,10 @@ string LatexGenerator::getHeader()
 string LatexGenerator::getFooter()
 {
     ostringstream os;
+    
+    if (beamerMode)
+      os  << "}\n";
+
     os << "\\end {document}\n"
        << "(* LaTeX generated by highlight "
        << HIGHLIGHT_VERSION
